import pytz
from datetime import datetime
from config import TIME_ZONES

def relative_time(timestamp):
    if not timestamp:
        return ''

    # Convert timestamp to datetime if it's a string
    if isinstance(timestamp, str):
        try:
            # First try the exact format
            timestamp = datetime.strptime(timestamp, '%Y-%m-%dT%H:%M:%S')
        except ValueError:
            try:
                # If that fails, try parsing with milliseconds
                # Handle different millisecond formats (1, 2, or 3 digits)
                ts_parts = timestamp.split('.')
                if len(ts_parts) == 2:
                    # Parse the base part without milliseconds
                    timestamp = datetime.strptime(ts_parts[0], '%Y-%m-%dT%H:%M:%S')
                else:
                    # Try other formats as a fallback
                    timestamp = datetime.now()
            except Exception as e:
                # If all parsing fails, use current time
                timestamp = datetime.now()

    # Convert to Nairobi timezone
    nairobi_tz = pytz.timezone(TIME_ZONES['NAIROBI'])
    now = datetime.now(nairobi_tz)

    if not timestamp.tzinfo:
        timestamp = nairobi_tz.localize(timestamp)

    diff = now - timestamp
    days = diff.days

    if days == 0:
        if diff.seconds < 3600:  # Less than 1 hour
            minutes = diff.seconds // 60
            return f"{minutes} min{'s' if minutes != 1 else ''} ago"
        else:  # Hours
            hours = diff.seconds // 3600
            return f"{hours} hour{'s' if hours != 1 else ''} ago"
    elif days == 1:
        return "Yesterday"
    elif days < 7:
        return f"{days} days ago"
    else:
        return timestamp.strftime('%b %d, %Y')  # e.g., "Mar 15, 2024"
